@@ -1,6 +1,8 @@
 """
 The cLasses and functions that representing the Python Client.
 """
+import archipelagos.common.data
+from archipelagos.common.data import parse_timestamp_str
 from archipelagos.common.data.collection import CollectionMetadataRequest, CollectionMetadataResponse
 from archipelagos.common.data.collection import CollectionRequest, CollectionResponse
 from archipelagos.common.data.filestore import FileStoreMetadataRequest, FileStoreMetadataResponse
@@ -698,8 +700,8 @@ class Archipelagos:
     def get_time_series(source: str,
                         code: str,
                         ts_id: str,
-                        start: Timestamp = None,
-                        end: Timestamp = None,
+                        start: Timestamp or str or None = None,
+                        end: Timestamp or str or None = None,
                         features: List[str] = None,
                         max_size: int = -1,
                         ascending: bool = True,
@@ -718,11 +720,11 @@ class Archipelagos:
         :param ts_id: The ID for the time-series.
         :type ts_id: str
 
-        :param start: The (optional) start date/time, or None.
-        :type start: Timestamp
+        :param start: The (optional) start date/time, or None; if a str is provided should be in YYYY-MM-dd[THH:mm:ss[%f]] format.
+        :type start: Timestamp or str or None
 
-        :param end: The (optional) end date/time, or None.
-        :type end: Timestamp
+        :param end: The (optional) end date/time, or None; if a str is provided should be in YYYY-MM-dd[THH:mm:ss[%f]] format.
+        :type end: Timestamp or str or None
 
         :param features: The (optional) list of features, or None.
         :type features: List[str] or None
@@ -750,6 +752,20 @@ class Archipelagos:
             return_numpy = "numpy" == returns or "np" == returns
 
             if return_pandas or return_numpy:
+                # See if we need to parse the start and end
+
+                if isinstance(start, str):
+                    try:
+                        start = parse_timestamp_str(start)
+                    except:
+                        raise ValueError("The value for the start parameter \"{}\" is unrecognised".format(returns))
+
+                if isinstance(end, str):
+                    try:
+                        end = parse_timestamp_str(end)
+                    except:
+                        raise ValueError("The value for the end parameter \"{}\" is unrecognised".format(returns))
+
                 # Send the time-series request to the platform
 
                 request = TimeSeriesRequest(source, code, ts_id, start, end, features, max_size, ascending, api_key)
