@@ -303,12 +303,12 @@ class CollectionMetadata:
     @staticmethod
     def deserialize(serialized: bytes) -> CollectionMetadata:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: Creates a new instance using a str created by serialize().
+        :return: Creates a new instance using bytes created by serialize().
         :rtype: CollectionMetadata
         """
         metadata = CollectionMetadata("a", "a", "a", "", "", "", dict(), dict(), False, Timestamp.now(), Timestamp.now())
@@ -317,9 +317,9 @@ class CollectionMetadata:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -562,12 +562,12 @@ class CollectionData:
     @staticmethod
     def deserialize(serialized: bytes) -> CollectionData:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: CollectionData
         """
         collection_data = CollectionData({})
@@ -577,9 +577,9 @@ class CollectionData:
     def _read_proto(self,
                     serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -716,12 +716,12 @@ class Collection:
     @staticmethod
     def deserialize(serialized: bytes) -> Collection:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: Collection
         """
         metadata = CollectionMetadata("a", "a", "a", "", "", "", dict(), dict(), False, Timestamp.now(), Timestamp.now())
@@ -733,9 +733,9 @@ class Collection:
     def _read_proto(self,
                     serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -909,12 +909,12 @@ class CollectionMetadataRequest:
     @staticmethod
     def deserialize(serialized: bytes) -> CollectionMetadataRequest:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: CollectionMetadataRequest
         """
         request = CollectionMetadataRequest("a", "a", "a", "a")
@@ -924,9 +924,9 @@ class CollectionMetadataRequest:
     def _read_proto(self,
                     serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -1065,9 +1065,9 @@ class CollectionMetadataResponse:
     @staticmethod
     def deserialize(serialized: bytes) -> CollectionMetadataResponse:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
         :return: A new instance using a bytes created by serialize().
@@ -1079,9 +1079,9 @@ class CollectionMetadataResponse:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
@@ -1337,12 +1337,12 @@ class CollectionRequest:
     @staticmethod
     def deserialize(serialized: bytes):
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: CollectionRequest
         """
         request = CollectionRequest("a", "a", "a", ["Example"], -1, {}, "a")
@@ -1352,15 +1352,10 @@ class CollectionRequest:
     def _read_proto(self,
                     serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        Parameters
-        ----------
-        serialized : str or bytes
-           The str produced by serialize().
-
-        :param : .
-        :type :
+        :param serialized : bytes produced by serialize().
+        :type serialized : str or bytes
         """
         byte_array = array.array('B', serialized)
         request = CollectionRequest_pb2.CollectionRequest()
@@ -1517,12 +1512,12 @@ class CollectionResponse:
     @staticmethod
     def deserialize(serialized: bytes) -> CollectionResponse:
         """
-        Creates a new instance using a str created by serialize().
+        Creates a new instance using bytes created by serialize().
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
 
-        :return: A new instance using a str created by serialize().
+        :return: A new instance using bytes created by serialize().
         :rtype: CollectionResponse
         """
         response = CollectionResponse(error_code=0, error_message="")
@@ -1531,9 +1526,9 @@ class CollectionResponse:
 
     def _read_proto(self, serialized: bytes):
         """
-        Sets the state of this from a str containing the state of an object serialised using Protobuf.
+        Sets the state of this from bytes containing the state of an object serialised using Protobuf.
 
-        :param serialized: The str produced by serialize().
+        :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
         byte_array = array.array('B', serialized)
